factor_labels: Read the factor labels stored on an ackwards object

View source: R/factor_labels.R

factor_labelsR Documentation

Read the factor labels stored on an ackwards object

Description

Read the factor labels stored on an ackwards object

Usage

factor_labels(x)

Arguments

x

An ackwards object.

Value

The named character vector of factor labels (names are factor IDs), or NULL if none have been set. See set_factor_labels() to attach them.

See Also

set_factor_labels()

Examples

x <- ackwards(sim16, k_max = 4, engine = "pca")
factor_labels(x) # NULL -- none set yet
x <- set_factor_labels(x, c(m4f1 = "Alpha"))
factor_labels(x)


ackwards documentation built on July 25, 2026, 1:08 a.m.